% CODE TO SOLVE EXERCISE 7.3

clear all
clc
close all


% a) calculating the temperature profile of the coldest point

% Glass jar characterisation
D = 5/100; %diameter in meters
H = 10/100; %height in meters
V = pi*H*(D/2)^2;% volume in cubic meters
A = 2*pi*(D/2)*H+2*pi*(D/2)^2; % surface area
Lc = V/A;% characteristic lenght

% Thermal diffusivity of the jam
alpha_jam = 0.122e-6; % m^2/s

% Thermal conductivity of the jam
k_jam = 0.12;% W/(m^2K)

% Time discretisation
t0 = 0;% initial time in seconds
tf = 3600;% final time in seconds
dt = 100;% timestep in seconds
time = t0:dt:tf;% vector of times
Fo = alpha_jam.*time/(D/2)^2;% vector of dimensionless times


% Spatial discretisation
ndisc = 31;% number of spatial nodes
rr    = linspace(0,1,ndisc);% vector of radial positions

% Heat transfer coefficient water bath
h_bath = 100;% W/Km^2

% Temperature of the water bath
Tbath = 86;% Celsius

% Initial temperature
Tini = 35;

% Biot number
Bi = h_bath*Lc/k_jam;

% Roots of  trasncendental equation: Bi J0(lambda) - lambda*J1(lambda)=0
m=0; 
M = 100; 

for n = 1:10000
    k1 = 0.05*n; k2 = 0.05*(n+1);
    y1 = Bi * besselj(0, k1) - k1 * besselj(1, k1);
    y2 = Bi * besselj(0, k2) - k2 * besselj(1, k2);
    if y1*y2 <= 0
        m = m+1;
        lambda (m) = k1;
    end
end


% Refining root values, Newton Raphson method
for n = 1:M
    for k = 1:5
f = Bi * besselj(0, lambda(n)) - lambda(n) * besselj(1, lambda(n));
df = 0.5*lambda(n)*(besselj(2, lambda(n))-besselj(0, lambda(n))) -(1+Bi) *besselj(1, lambda(n));
lambda(n) = lambda(n) - f/df;
    end
end


% Fourier coefficients
for m = 1:M
a(m) = 2 * besselj(1,lambda(m)) / (lambda(m)*(besselj(0,lambda(m))^2+besselj(1,lambda(m))^2));
end

% Initialisation 
dimT = zeros(length(Fo), length(rr));

% Grid
rdim = repmat (rr,[length(Fo) 1]);
tdim = repmat (Fo',[1 length(rr)]);

% Analytical solution
for m = 1:M
    %Dimensionless temperatures
    dimT = dimT + a(m)*besselj(0,lambda(m)*rdim).*exp(-lambda(m)*lambda(m)*tdim);
end

% Real temperature
TT = dimT*(Tini-Tbath) + Tbath;

% Plotting temperature-time profile at the center of the jar
figure
axes('fontsize',14)
plot(time,TT(:,1),'o','Linewidth',2)
xlabel('Time (seconds)')
ylabel('Temperature (Celsius)')

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% b) Calculating the P-value

% Reference temperature
Tref = 93.3;% Celsius

% z-value
z = 8.9;% Celsius

% Fvalue in time
p  = 10.^((TT(:,1)-Tref)/z);

% F-value for the whole process
P  = dt*trapz(p)/60 % in minutes