
%% Parameters
    
    %Mass Balances.
    M4=250; %kg/h
    xwaterM1=0.8;
    xwaterM1secondcase=0.9;
    wastepercentage=0.02;
    targetmoist=0.08;
    CacaoContent=0.10;
    SugarContent=0.20;
    
    %Energy balances.
    Troom=20;
    Twetslurryin=85;    % Celsius
    Tdry=100;
    Tdrysecondcase=120;
    DeltaHvap100=2258.9;     % kJ/kg 100 C
    DeltaHvap120=2202.2;     % kJ/kg 100 C
    DeltaHgelat=10; %kJ/kg
    
    %Oat Content.
    xprotoat=0.17;
    xfatoat=0.11;
    xcarbohoat=0.22;
    xfiboat=0.42;
    xashoat=0.08;

    %Nutrients specific Heat %kJ/kg 
    cpprot=2.0082+0.0012089*((Tdry+Twetslurryin)/2)-0.0000013129*((Tdry+Twetslurryin)/2)^2;
    cpfat=1.9842+0.0014733*Tdry-0.0000048008*((Tdry+Twetslurryin)/2)^2;
    cpcarboh=1.5488+0.0019625*((Tdry+Twetslurryin)/2)-0.0000059399*((Tdry+Twetslurryin)/2)^2;
    cpfib=1.8459+0.0018306*((Tdry+Twetslurryin)/2)-0.0000046509*((Tdry+Twetslurryin)/2)^2;
    cpash=1.0926+0.0018896*((Tdry+Twetslurryin)/2)-0.0000036817*((Tdry+Twetslurryin)/2)^2;
    cpwater=4.22;  
    
    %Electricity Consumption for equipment (kW).
    MillElec=3;
    WetMixingElec=4;
    StirredTankElec=1;
    DryerElec=4;
    ConveyorCoolingElec=5;
    DryMixingElec=2;
    PackagingElec=4;
    %Density kg/m3
%     rhoprot=1329.9-0.5184*Twetslurryin;         %kg/m3
%     rhofat=925.59-0.41757*Twetslurryin;
%     rhocarboh=1599.1-0.31046*Twetslurryin;
%     rhofib=1311.55-0.36589*Twetslurryin;
%     rhoash=2423.8-0.28063*Twetslurryin;
%     rhowater=971.6;          %kg/m3  (80C)
    
    %Double Drum Dryer Design.
    
    slurrythickness=0.0005; %m
    positionblades=3/4;
    L=1.5;   %m
    D=0.75;    %m
    rotspeedmin=1.5;        %rpm
    rotspeedmax=10;         %rpm

%     powerDDDmin=15.000;      %kW
%     powerDDDmax=35.000;      %kW
    
    % Boundaries
    Tsteamlb=100;       % Celsius
    Tsteamub=250;
    
    Numberofshots=10;
    
    
%% Mass Balances

%Drying 
M4Water=targetmoist*M4;        %kg/h
M4Flour=(1-targetmoist)*M4;
M1Flour=M4Flour*(1/(1-wastepercentage));
M1=M1Flour/(1-xwaterM1secondcase);
M1Water=M1*xwaterM1secondcase;
M2=wastepercentage*M1Flour;
M3=M1Water-M4Water;

%Gelatinization 
M5=M1/(1-wastepercentage);
M6=wastepercentage*M1/(1-wastepercentage);

%Wet Mixing
MWMin=M5/(1-wastepercentage);  %water + flour
M7=MWMin*(1-xwaterM1secondcase);  %flour
M8=MWMin*xwaterM1secondcase;      %water
M9=wastepercentage*MWMin;

%Milling flour
M10=M7/(1-wastepercentage);

%Cooling (No waste)
M11=M4;

%Dry Mixing
M12=M11*SugarContent;
M13=M11*CacaoContent;
M14=(M11+M12+M13)*(1-wastepercentage);    %Final Product
M15=M14*wastepercentage;    %waste

%Milling Ingredients;
M16=M12/(1-wastepercentage);
M17=M14/(1-wastepercentage);


%% Energy Balances

cpoatflour=xprotoat*cpprot+xfatoat*cpfat+xcarbohoat*cpcarboh+xfiboat*cpfib+xashoat*cpash;
cpwetslurry=xwaterM1secondcase*cpwater+(1-xwaterM1secondcase)*cpoatflour;

%Drying
QlatH2O=M3*DeltaHvap100;       %kJ/h
Qsensiblewetslurry=M1*cpwetslurry*(Tdry-Twetslurryin); %kJ/h
Qtotaldry=QlatH2O+Qsensiblewetslurry;               %kJ/h           

%Gelatinization

Qheatingslurry=M5*cpwetslurry*(Twetslurryin-Troom);      %kJ/h
Qgelat=M5*DeltaHgelat;
Qtotalgelatin=Qheatingslurry+Qgelat;

%Cooling

Tcoolav=(Tdry+Troom)/2;
cpdryslurry=targetmoist*cpwater+(1-targetmoist)*cpoatflour;
Qremovcool=M4*cpdryslurry*(Tdry-Troom);     %kJ/h


%% Whole energy Consumption Each Stage. kW

Milling1=MillElec;
WetMixing=WetMixingElec;
Gelatinization=Qtotalgelatin*(1/3600)+StirredTankElec;
Drying=Qtotaldry*(1/3600)+DryerElec;
Cooling=ConveyorCoolingElec;
CoolingHeatRemoved=-Qremovcool*(1/3600);
Milling2=2*MillElec;
DryMixing=DryMixingElec;
Packaging=PackagingElec;
   
TotalEnergyConsumption=Milling1+WetMixing+Gelatinization+Drying+Cooling+(-CoolingHeatRemoved)+Milling2+DryMixing+Packaging;
